{
  "Comment-DrE": {
    "target_type": "Comment",
    "heading": "Comment-DrE Attributes",
    "description": "Auto-generated format for Comment (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Feedback Manager",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Associated Element",
            "key": "associated_element",
            "format": false
          },
          {
            "name": "Comment Text",
            "key": "comment_text",
            "format": false
          },
          {
            "name": "Comment Type",
            "key": "comment_type",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Associated Element",
            "key": "associated_element",
            "format": false
          },
          {
            "name": "Comment Text",
            "key": "comment_text",
            "format": false
          },
          {
            "name": "Comment Type",
            "key": "comment_type",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {}
    },
    "get_additional_props": null
  },
  "NoteLog-DrE": {
    "target_type": "NoteLog",
    "heading": "NoteLog-DrE Attributes",
    "description": "Auto-generated format for NoteLog (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Feedback Manager",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Journal Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Associated Element",
            "key": "associated_element",
            "format": false
          },
          {
            "name": "Journal Description",
            "key": "journal_description",
            "format": false
          },
          {
            "name": "Note Entry",
            "key": "note_entry",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Journal Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Associated Element",
            "key": "associated_element",
            "format": false
          },
          {
            "name": "Journal Description",
            "key": "journal_description",
            "format": false
          },
          {
            "name": "Note Entry",
            "key": "note_entry",
            "format": false
          }
        ]
      }
    ],
    "action": null,
    "get_additional_props": null
  },
  "Informal-Tag-DrE": {
    "target_type": "Informal Tag",
    "heading": "Informal-Tag-DrE Attributes",
    "description": "Auto-generated format for Informal Tag (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Feedback Manager",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          }
        ]
      }
    ],
    "action": null,
    "get_additional_props": null
  },
  "External-Reference-DrE": {
    "target_type": "External Reference",
    "heading": "External-Reference-DrE Attributes",
    "description": "Auto-generated format for External Reference (Create).",
    "aliases": [],
    "annotations": {},
    "family": "External Reference",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Reference Title",
            "key": "reference_title",
            "format": false
          },
          {
            "name": "Reference Abstract",
            "key": "reference_abstract",
            "format": false
          },
          {
            "name": "Authors",
            "key": "authors",
            "format": false
          },
          {
            "name": "Organization",
            "key": "organization",
            "format": false
          },
          {
            "name": "Sources",
            "key": "reference_sources",
            "format": false
          },
          {
            "name": "License",
            "key": "license",
            "format": false
          },
          {
            "name": "Copyright",
            "key": "copyright",
            "format": false
          },
          {
            "name": "Attribution",
            "key": "category",
            "format": false
          },
          {
            "name": "Number of Pages",
            "key": "number_of_pages",
            "format": false
          },
          {
            "name": "Page Range",
            "key": "page_range",
            "format": false
          },
          {
            "name": "Publication Series",
            "key": "publication_series",
            "format": false
          },
          {
            "name": "Publication Series Volume",
            "key": "pub_series_volume",
            "format": false
          },
          {
            "name": "Publisher",
            "key": "publisher",
            "format": false
          },
          {
            "name": "First Publication Date",
            "key": "first_pub_date",
            "format": false
          },
          {
            "name": "Publication Date",
            "key": "pub_date",
            "format": false
          },
          {
            "name": "Publication City",
            "key": "pub_city",
            "format": false
          },
          {
            "name": "Publication Year",
            "key": "pub_year",
            "format": false
          },
          {
            "name": "Publication Numbers",
            "key": "pub_numbers",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Reference Title",
            "key": "reference_title",
            "format": false
          },
          {
            "name": "Reference Abstract",
            "key": "reference_abstract",
            "format": false
          },
          {
            "name": "Authors",
            "key": "authors",
            "format": false
          },
          {
            "name": "Organization",
            "key": "organization",
            "format": false
          },
          {
            "name": "Sources",
            "key": "reference_sources",
            "format": false
          },
          {
            "name": "License",
            "key": "license",
            "format": false
          },
          {
            "name": "Copyright",
            "key": "copyright",
            "format": false
          },
          {
            "name": "Attribution",
            "key": "category",
            "format": false
          },
          {
            "name": "Number of Pages",
            "key": "number_of_pages",
            "format": false
          },
          {
            "name": "Page Range",
            "key": "page_range",
            "format": false
          },
          {
            "name": "Publication Series",
            "key": "publication_series",
            "format": false
          },
          {
            "name": "Publication Series Volume",
            "key": "pub_series_volume",
            "format": false
          },
          {
            "name": "Publisher",
            "key": "publisher",
            "format": false
          },
          {
            "name": "First Publication Date",
            "key": "first_pub_date",
            "format": false
          },
          {
            "name": "Publication Date",
            "key": "pub_date",
            "format": false
          },
          {
            "name": "Publication City",
            "key": "pub_city",
            "format": false
          },
          {
            "name": "Publication Year",
            "key": "pub_year",
            "format": false
          },
          {
            "name": "Publication Numbers",
            "key": "pub_numbers",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "ExternalReference.find_external_references",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "CitedDocument"
        ]
      }
    },
    "get_additional_props": null
  },
  "External-Data-Source-DrE": {
    "target_type": "External Data Source",
    "heading": "External-Data-Source-DrE Attributes",
    "description": "Auto-generated format for External Data Source (Create).",
    "aliases": [],
    "annotations": {},
    "family": "External Reference",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Reference Title",
            "key": "reference_title",
            "format": false
          },
          {
            "name": "Reference Abstract",
            "key": "reference_abstract",
            "format": false
          },
          {
            "name": "Authors",
            "key": "authors",
            "format": false
          },
          {
            "name": "Organization",
            "key": "organization",
            "format": false
          },
          {
            "name": "Sources",
            "key": "reference_sources",
            "format": false
          },
          {
            "name": "License",
            "key": "license",
            "format": false
          },
          {
            "name": "Copyright",
            "key": "copyright",
            "format": false
          },
          {
            "name": "Attribution",
            "key": "category",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Reference Title",
            "key": "reference_title",
            "format": false
          },
          {
            "name": "Reference Abstract",
            "key": "reference_abstract",
            "format": false
          },
          {
            "name": "Authors",
            "key": "authors",
            "format": false
          },
          {
            "name": "Organization",
            "key": "organization",
            "format": false
          },
          {
            "name": "Sources",
            "key": "reference_sources",
            "format": false
          },
          {
            "name": "License",
            "key": "license",
            "format": false
          },
          {
            "name": "Copyright",
            "key": "copyright",
            "format": false
          },
          {
            "name": "Attribution",
            "key": "category",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "ExternalReference.find_external_references",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "ExternalDataSource"
        ]
      }
    },
    "get_additional_props": null
  },
  "Collection-DrE": {
    "target_type": "Collection",
    "heading": "Collection-DrE Attributes",
    "description": "Auto-generated format for Collection (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Digital Product Manager",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "CollectionManager.find_collections",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {}
    },
    "get_additional_props": null
  },
  "Digital-Product-Catalog-DrE": {
    "target_type": "Digital Product Catalog",
    "heading": "Digital-Product-Catalog-DrE Attributes",
    "description": "Auto-generated format for Digital Product Catalog (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Digital Product Manager",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          }
        ]
      }
    ],
    "action": null,
    "get_additional_props": null
  },
  "Digital-Product-DrE": {
    "target_type": "Digital Product",
    "heading": "Digital-Product-DrE Attributes",
    "description": "Auto-generated format for Digital Product (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Digital Product Manager",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Product Name",
            "key": "product_name",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Maturity",
            "key": "maturity",
            "format": false
          },
          {
            "name": "Service Life",
            "key": "service_life",
            "format": false
          },
          {
            "name": "Introduction Date",
            "key": "introduction_date",
            "format": false
          },
          {
            "name": "Next Version Date",
            "key": "next_version_date",
            "format": false
          },
          {
            "name": "Withdrawal Date",
            "key": "withdrawal_date",
            "format": false
          },
          {
            "name": "Product Manager",
            "key": "product_manager",
            "format": false
          },
          {
            "name": "Agreements",
            "key": "agreements",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Product Name",
            "key": "product_name",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Maturity",
            "key": "maturity",
            "format": false
          },
          {
            "name": "Service Life",
            "key": "service_life",
            "format": false
          },
          {
            "name": "Introduction Date",
            "key": "introduction_date",
            "format": false
          },
          {
            "name": "Next Version Date",
            "key": "next_version_date",
            "format": false
          },
          {
            "name": "Withdrawal Date",
            "key": "withdrawal_date",
            "format": false
          },
          {
            "name": "Product Manager",
            "key": "product_manager",
            "format": false
          },
          {
            "name": "Agreements",
            "key": "agreements",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "CollectionManager.find_collections",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "DigitalProduct"
        ]
      }
    },
    "get_additional_props": null
  },
  "Agreement-DrE": {
    "target_type": "Agreement",
    "heading": "Agreement-DrE Attributes",
    "description": "Auto-generated format for Agreement (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Digital Product Manager",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "agreement_identifier",
            "format": false
          },
          {
            "name": "Agreement Actors",
            "key": "agreement_actors",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "agreement_identifier",
            "format": false
          },
          {
            "name": "Agreement Actors",
            "key": "agreement_actors",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "CollectionManager.find_collections",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "Agreement"
        ]
      }
    },
    "get_additional_props": null
  },
  "Data-Sharing-Agreement-DrE": {
    "target_type": "Data Sharing Agreement",
    "heading": "Data-Sharing-Agreement-DrE Attributes",
    "description": "Auto-generated format for Data Sharing Agreement (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Digital Product Manager",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Product Manager",
            "key": "product_manager",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Product Manager",
            "key": "product_manager",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "CollectionManager.find_collections",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "classification_names": [
          "DataSharingAgreement"
        ]
      }
    },
    "get_additional_props": null
  },
  "Digital-Subscription-DrE": {
    "target_type": "Digital Subscription",
    "heading": "Digital-Subscription-DrE Attributes",
    "description": "Auto-generated format for Digital Subscription (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Digital Product Manager",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Support Level",
            "key": "support_level",
            "format": false
          },
          {
            "name": "Service Levels",
            "key": "service_levels",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Support Level",
            "key": "support_level",
            "format": false
          },
          {
            "name": "Service Levels",
            "key": "service_levels",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "CollectionManager.find_collections",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "DigitalSubscription"
        ]
      }
    },
    "get_additional_props": null
  },
  "CSV-File-DrE": {
    "target_type": "CSV File",
    "heading": "CSV-File-DrE Attributes",
    "description": "Auto-generated format for CSV File (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Digital Product Manager",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "File Path",
            "key": "file_path",
            "format": false
          },
          {
            "name": "File Encoding",
            "key": "file_encoding",
            "format": false
          },
          {
            "name": "File Extension",
            "key": "file_extension",
            "format": false
          },
          {
            "name": "File System Name",
            "key": "file_system_name",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "File Path",
            "key": "file_path",
            "format": false
          },
          {
            "name": "File Encoding",
            "key": "file_encoding",
            "format": false
          },
          {
            "name": "File Extension",
            "key": "file_extension",
            "format": false
          },
          {
            "name": "File System Name",
            "key": "file_system_name",
            "format": false
          }
        ]
      }
    ],
    "action": null,
    "get_additional_props": null
  },
  "Data-Dictionary-DrE": {
    "target_type": "Data Dictionary",
    "heading": "Data-Dictionary-DrE Attributes",
    "description": "Auto-generated format for Data Dictionary (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Data Designer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "CollectionManager.find_collections",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "DataDictionary"
        ]
      }
    },
    "get_additional_props": null
  },
  "Data-Specification-DrE": {
    "target_type": "Data Specification",
    "heading": "Data-Specification-DrE Attributes",
    "description": "Auto-generated format for Data Specification (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Data Designer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "CollectionManager.find_collections",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "DataSpec"
        ]
      }
    },
    "get_additional_props": null
  },
  "Data-Structure-DrE": {
    "target_type": "Data Structure",
    "heading": "Data-Structure-DrE Attributes",
    "description": "Auto-generated format for Data Structure (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Data Designer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "In Data Specification",
            "key": "in_data_spec",
            "format": false
          },
          {
            "name": "In Data Dictionary",
            "key": "in_data_dictionary",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "In Data Specification",
            "key": "in_data_spec",
            "format": false
          },
          {
            "name": "In Data Dictionary",
            "key": "in_data_dictionary",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "DataDesigner.find_data_structures",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {}
    },
    "get_additional_props": null
  },
  "Data-Field-DrE": {
    "target_type": "Data Field",
    "heading": "Data-Field-DrE Attributes",
    "description": "Auto-generated format for Data Field (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Data Designer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Data Type",
            "key": "data_type",
            "format": false
          },
          {
            "name": "Position",
            "key": "position",
            "format": false
          },
          {
            "name": "Minimum Cardinality",
            "key": "min_cardinality",
            "format": false
          },
          {
            "name": "Maximum Cardinality",
            "key": "max_cardinality",
            "format": false
          },
          {
            "name": "In Data Structure",
            "key": "in_data_structure",
            "format": false
          },
          {
            "name": "In Data Dictionary",
            "key": "in_data_dictionary",
            "format": false
          },
          {
            "name": "Data Class",
            "key": "data_class",
            "format": false
          },
          {
            "name": "isNullable",
            "key": "is_nullable",
            "format": false
          },
          {
            "name": "Minimum Length",
            "key": "min_length",
            "format": false
          },
          {
            "name": "Length",
            "key": "length",
            "format": false
          },
          {
            "name": "Precision",
            "key": "precision",
            "format": false
          },
          {
            "name": "Ordered Values",
            "key": "ordered_values",
            "format": false
          },
          {
            "name": "Units",
            "key": "units",
            "format": false
          },
          {
            "name": "Default Value",
            "key": "default_value",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Data Type",
            "key": "data_type",
            "format": false
          },
          {
            "name": "Position",
            "key": "position",
            "format": false
          },
          {
            "name": "Minimum Cardinality",
            "key": "min_cardinality",
            "format": false
          },
          {
            "name": "Maximum Cardinality",
            "key": "max_cardinality",
            "format": false
          },
          {
            "name": "In Data Structure",
            "key": "in_data_structure",
            "format": false
          },
          {
            "name": "In Data Dictionary",
            "key": "in_data_dictionary",
            "format": false
          },
          {
            "name": "Data Class",
            "key": "data_class",
            "format": false
          },
          {
            "name": "isNullable",
            "key": "is_nullable",
            "format": false
          },
          {
            "name": "Minimum Length",
            "key": "min_length",
            "format": false
          },
          {
            "name": "Length",
            "key": "length",
            "format": false
          },
          {
            "name": "Precision",
            "key": "precision",
            "format": false
          },
          {
            "name": "Ordered Values",
            "key": "ordered_values",
            "format": false
          },
          {
            "name": "Units",
            "key": "units",
            "format": false
          },
          {
            "name": "Default Value",
            "key": "default_value",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "DataDesigner.find_data_fields",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {}
    },
    "get_additional_props": null
  },
  "Data-Class-DrE": {
    "target_type": "Data Class",
    "heading": "Data-Class-DrE Attributes",
    "description": "Auto-generated format for Data Class (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Data Designer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Namespace",
            "key": "namespace",
            "format": false
          },
          {
            "name": "Match Property Names",
            "key": "match_property_names",
            "format": false
          },
          {
            "name": "Match Threshold",
            "key": "match_threshold",
            "format": false
          },
          {
            "name": "IsCaseSensitive",
            "key": "is_case_sensitive",
            "format": false
          },
          {
            "name": "Data Type",
            "key": "data_type",
            "format": false
          },
          {
            "name": "Allow Duplicate Values",
            "key": "duplicates_allowed",
            "format": false
          },
          {
            "name": "isNullable",
            "key": "is_nullable",
            "format": false
          },
          {
            "name": "Default Value",
            "key": "default_value",
            "format": false
          },
          {
            "name": "Average Value",
            "key": "avg_value",
            "format": false
          },
          {
            "name": "Value List",
            "key": "value_list",
            "format": false
          },
          {
            "name": "Value Range From",
            "key": "value_range_from",
            "format": false
          },
          {
            "name": "Value Range To",
            "key": "value_range_to",
            "format": false
          },
          {
            "name": "Sample Values",
            "key": "sample_values",
            "format": false
          },
          {
            "name": "Data Patterns",
            "key": "data_patterns",
            "format": false
          },
          {
            "name": "In Data Dictionary",
            "key": "in_data_dictionary",
            "format": false
          },
          {
            "name": "Containing Data Class",
            "key": "containing_data_class",
            "format": false
          },
          {
            "name": "Specializes Data Class",
            "key": "specializes_data_class",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Namespace",
            "key": "namespace",
            "format": false
          },
          {
            "name": "Match Property Names",
            "key": "match_property_names",
            "format": false
          },
          {
            "name": "Match Threshold",
            "key": "match_threshold",
            "format": false
          },
          {
            "name": "IsCaseSensitive",
            "key": "is_case_sensitive",
            "format": false
          },
          {
            "name": "Data Type",
            "key": "data_type",
            "format": false
          },
          {
            "name": "Allow Duplicate Values",
            "key": "duplicates_allowed",
            "format": false
          },
          {
            "name": "isNullable",
            "key": "is_nullable",
            "format": false
          },
          {
            "name": "Default Value",
            "key": "default_value",
            "format": false
          },
          {
            "name": "Average Value",
            "key": "avg_value",
            "format": false
          },
          {
            "name": "Value List",
            "key": "value_list",
            "format": false
          },
          {
            "name": "Value Range From",
            "key": "value_range_from",
            "format": false
          },
          {
            "name": "Value Range To",
            "key": "value_range_to",
            "format": false
          },
          {
            "name": "Sample Values",
            "key": "sample_values",
            "format": false
          },
          {
            "name": "Data Patterns",
            "key": "data_patterns",
            "format": false
          },
          {
            "name": "In Data Dictionary",
            "key": "in_data_dictionary",
            "format": false
          },
          {
            "name": "Containing Data Class",
            "key": "containing_data_class",
            "format": false
          },
          {
            "name": "Specializes Data Class",
            "key": "specializes_data_class",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "DataDesigner.find_data_classes",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {}
    },
    "get_additional_props": null
  },
  "Information-Supply-Chain-DrE": {
    "target_type": "Information Supply Chain",
    "heading": "Information-Supply-Chain-DrE Attributes",
    "description": "Auto-generated format for Information Supply Chain (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Solution Architect",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Purposes",
            "key": "purposes",
            "format": false
          },
          {
            "name": "Nested Information Supply Chains",
            "key": "nested_info_supply_chains",
            "format": false
          },
          {
            "name": "In Information Supply Chain",
            "key": "in_supply_chain",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Purposes",
            "key": "purposes",
            "format": false
          },
          {
            "name": "Nested Information Supply Chains",
            "key": "nested_info_supply_chains",
            "format": false
          },
          {
            "name": "In Information Supply Chain",
            "key": "in_supply_chain",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "SolutionArchitect.find_information_supply_chains",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {}
    },
    "get_additional_props": null
  },
  "Solution-Blueprint-DrE": {
    "target_type": "Solution Blueprint",
    "heading": "Solution-Blueprint-DrE Attributes",
    "description": "Auto-generated format for Solution Blueprint (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Solution Architect",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Solution Components",
            "key": "solution_components",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Solution Components",
            "key": "solution_components",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "SolutionArchitect.find_solution_blueprints",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {}
    },
    "get_additional_props": null
  },
  "Solution-Component-DrE": {
    "target_type": "Solution Component",
    "heading": "Solution-Component-DrE Attributes",
    "description": "Auto-generated format for Solution Component (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Solution Architect",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Solution Component Type",
            "key": "soln_comp_type",
            "format": false
          },
          {
            "name": "Planned Deployed Implementation Type",
            "key": "planned_deployed_impl_type",
            "format": false
          },
          {
            "name": "In Solution Components",
            "key": "in_components",
            "format": false
          },
          {
            "name": "In Solution Blueprints",
            "key": "solution_blueprints",
            "format": false
          },
          {
            "name": "In Information Supply Chains",
            "key": "in_supply_chains",
            "format": false
          },
          {
            "name": "Actors",
            "key": "actors",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Solution Component Type",
            "key": "soln_comp_type",
            "format": false
          },
          {
            "name": "Planned Deployed Implementation Type",
            "key": "planned_deployed_impl_type",
            "format": false
          },
          {
            "name": "In Solution Components",
            "key": "in_components",
            "format": false
          },
          {
            "name": "In Solution Blueprints",
            "key": "solution_blueprints",
            "format": false
          },
          {
            "name": "In Information Supply Chains",
            "key": "in_supply_chains",
            "format": false
          },
          {
            "name": "Actors",
            "key": "actors",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "SolutionArchitect.find_solution_components",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {}
    },
    "get_additional_props": null
  },
  "Solution-Role-DrE": {
    "target_type": "Solution Role",
    "heading": "Solution-Role-DrE Attributes",
    "description": "Auto-generated format for Solution Role (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Solution Architect",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Name",
            "key": "name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Title",
            "key": "title",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Name",
            "key": "name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Title",
            "key": "title",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "SolutionArchitect.find_solution_roles",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {}
    },
    "get_additional_props": null
  },
  "Glossary-DrE": {
    "target_type": "Glossary",
    "heading": "Glossary-DrE Attributes",
    "description": "Auto-generated format for Glossary (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Glossary",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Language",
            "key": "language",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Language",
            "key": "language",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "CollectionManager.find_collections",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "Glossary"
        ]
      }
    },
    "get_additional_props": null
  },
  "Glossary-Term-DrE": {
    "target_type": "Glossary Term",
    "heading": "Glossary-Term-DrE Attributes",
    "description": "Auto-generated format for Glossary Term (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Glossary",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "term_name",
            "format": false
          },
          {
            "name": "Glossary",
            "key": "glossary_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Folders",
            "key": "folders",
            "format": false
          },
          {
            "name": "Abbreviation",
            "key": "abbreviation",
            "format": false
          },
          {
            "name": "Example",
            "key": "example",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "term_name",
            "format": false
          },
          {
            "name": "Glossary",
            "key": "glossary_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Folders",
            "key": "folders",
            "format": false
          },
          {
            "name": "Abbreviation",
            "key": "abbreviation",
            "format": false
          },
          {
            "name": "Example",
            "key": "example",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GlossaryManager.find_glossary_terms",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {}
    },
    "get_additional_props": null
  },
  "Project-DrE": {
    "target_type": "Project",
    "heading": "Project-DrE Attributes",
    "description": "Auto-generated format for Project (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Project",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Project Type",
            "key": "project_type",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "project_identifier",
            "format": false
          },
          {
            "name": "Mission",
            "key": "mission",
            "format": false
          },
          {
            "name": "Purposes",
            "key": "purposes",
            "format": false
          },
          {
            "name": "Start Date",
            "key": "start_date",
            "format": false
          },
          {
            "name": "Planned End Date",
            "key": "end_date",
            "format": false
          },
          {
            "name": "Priority",
            "key": "priority",
            "format": false
          },
          {
            "name": "Project Phase",
            "key": "project_phase",
            "format": false
          },
          {
            "name": "Project Status",
            "key": "project_status",
            "format": false
          },
          {
            "name": "Project Health",
            "key": "project_health",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Project Type",
            "key": "project_type",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "project_identifier",
            "format": false
          },
          {
            "name": "Mission",
            "key": "mission",
            "format": false
          },
          {
            "name": "Purposes",
            "key": "purposes",
            "format": false
          },
          {
            "name": "Start Date",
            "key": "start_date",
            "format": false
          },
          {
            "name": "Planned End Date",
            "key": "end_date",
            "format": false
          },
          {
            "name": "Priority",
            "key": "priority",
            "format": false
          },
          {
            "name": "Project Phase",
            "key": "project_phase",
            "format": false
          },
          {
            "name": "Project Status",
            "key": "project_status",
            "format": false
          },
          {
            "name": "Project Health",
            "key": "project_health",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "ProjectManager.find_projects",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {}
    },
    "get_additional_props": null
  },
  "Campaign-DrE": {
    "target_type": "Campaign",
    "heading": "Campaign-DrE Attributes",
    "description": "Auto-generated format for Campaign (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Project",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Project Type",
            "key": "project_type",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "project_identifier",
            "format": false
          },
          {
            "name": "Mission",
            "key": "mission",
            "format": false
          },
          {
            "name": "Purposes",
            "key": "purposes",
            "format": false
          },
          {
            "name": "Start Date",
            "key": "start_date",
            "format": false
          },
          {
            "name": "Planned End Date",
            "key": "end_date",
            "format": false
          },
          {
            "name": "Priority",
            "key": "priority",
            "format": false
          },
          {
            "name": "Project Phase",
            "key": "project_phase",
            "format": false
          },
          {
            "name": "Project Status",
            "key": "project_status",
            "format": false
          },
          {
            "name": "Project Health",
            "key": "project_health",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Project Type",
            "key": "project_type",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "project_identifier",
            "format": false
          },
          {
            "name": "Mission",
            "key": "mission",
            "format": false
          },
          {
            "name": "Purposes",
            "key": "purposes",
            "format": false
          },
          {
            "name": "Start Date",
            "key": "start_date",
            "format": false
          },
          {
            "name": "Planned End Date",
            "key": "end_date",
            "format": false
          },
          {
            "name": "Priority",
            "key": "priority",
            "format": false
          },
          {
            "name": "Project Phase",
            "key": "project_phase",
            "format": false
          },
          {
            "name": "Project Status",
            "key": "project_status",
            "format": false
          },
          {
            "name": "Project Health",
            "key": "project_health",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "ProjectManager.find_projects",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "classification_names": [
          "Campaign"
        ]
      }
    },
    "get_additional_props": null
  },
  "Task-DrE": {
    "target_type": "Task",
    "heading": "Task-DrE Attributes",
    "description": "Auto-generated format for Task (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Project",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Project Type",
            "key": "project_type",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "project_identifier",
            "format": false
          },
          {
            "name": "Mission",
            "key": "mission",
            "format": false
          },
          {
            "name": "Purposes",
            "key": "purposes",
            "format": false
          },
          {
            "name": "Start Date",
            "key": "start_date",
            "format": false
          },
          {
            "name": "Planned End Date",
            "key": "end_date",
            "format": false
          },
          {
            "name": "Priority",
            "key": "priority",
            "format": false
          },
          {
            "name": "Project Phase",
            "key": "project_phase",
            "format": false
          },
          {
            "name": "Project Status",
            "key": "project_status",
            "format": false
          },
          {
            "name": "Project Health",
            "key": "project_health",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Project Type",
            "key": "project_type",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "project_identifier",
            "format": false
          },
          {
            "name": "Mission",
            "key": "mission",
            "format": false
          },
          {
            "name": "Purposes",
            "key": "purposes",
            "format": false
          },
          {
            "name": "Start Date",
            "key": "start_date",
            "format": false
          },
          {
            "name": "Planned End Date",
            "key": "end_date",
            "format": false
          },
          {
            "name": "Priority",
            "key": "priority",
            "format": false
          },
          {
            "name": "Project Phase",
            "key": "project_phase",
            "format": false
          },
          {
            "name": "Project Status",
            "key": "project_status",
            "format": false
          },
          {
            "name": "Project Health",
            "key": "project_health",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "ProjectManager.find_projects",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "classification_names": [
          "Task"
        ]
      }
    },
    "get_additional_props": null
  },
  "Personal-Project-DrE": {
    "target_type": "Personal Project",
    "heading": "Personal-Project-DrE Attributes",
    "description": "Auto-generated format for Personal Project (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Project",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Project Type",
            "key": "project_type",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "project_identifier",
            "format": false
          },
          {
            "name": "Mission",
            "key": "mission",
            "format": false
          },
          {
            "name": "Purposes",
            "key": "purposes",
            "format": false
          },
          {
            "name": "Start Date",
            "key": "start_date",
            "format": false
          },
          {
            "name": "Planned End Date",
            "key": "end_date",
            "format": false
          },
          {
            "name": "Priority",
            "key": "priority",
            "format": false
          },
          {
            "name": "Project Phase",
            "key": "project_phase",
            "format": false
          },
          {
            "name": "Project Status",
            "key": "project_status",
            "format": false
          },
          {
            "name": "Project Health",
            "key": "project_health",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Project Type",
            "key": "project_type",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "project_identifier",
            "format": false
          },
          {
            "name": "Mission",
            "key": "mission",
            "format": false
          },
          {
            "name": "Purposes",
            "key": "purposes",
            "format": false
          },
          {
            "name": "Start Date",
            "key": "start_date",
            "format": false
          },
          {
            "name": "Planned End Date",
            "key": "end_date",
            "format": false
          },
          {
            "name": "Priority",
            "key": "priority",
            "format": false
          },
          {
            "name": "Project Phase",
            "key": "project_phase",
            "format": false
          },
          {
            "name": "Project Status",
            "key": "project_status",
            "format": false
          },
          {
            "name": "Project Health",
            "key": "project_health",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "ProjectManager.find_projects",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "classification_names": [
          "PersonalProject"
        ]
      }
    },
    "get_additional_props": null
  },
  "Study-Project-DrE": {
    "target_type": "Study Project",
    "heading": "Study-Project-DrE Attributes",
    "description": "Auto-generated format for Study Project (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Project",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Project Type",
            "key": "project_type",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "project_identifier",
            "format": false
          },
          {
            "name": "Mission",
            "key": "mission",
            "format": false
          },
          {
            "name": "Purposes",
            "key": "purposes",
            "format": false
          },
          {
            "name": "Start Date",
            "key": "start_date",
            "format": false
          },
          {
            "name": "Planned End Date",
            "key": "end_date",
            "format": false
          },
          {
            "name": "Priority",
            "key": "priority",
            "format": false
          },
          {
            "name": "Project Phase",
            "key": "project_phase",
            "format": false
          },
          {
            "name": "Project Status",
            "key": "project_status",
            "format": false
          },
          {
            "name": "Project Health",
            "key": "project_health",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Project Type",
            "key": "project_type",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "project_identifier",
            "format": false
          },
          {
            "name": "Mission",
            "key": "mission",
            "format": false
          },
          {
            "name": "Purposes",
            "key": "purposes",
            "format": false
          },
          {
            "name": "Start Date",
            "key": "start_date",
            "format": false
          },
          {
            "name": "Planned End Date",
            "key": "end_date",
            "format": false
          },
          {
            "name": "Priority",
            "key": "priority",
            "format": false
          },
          {
            "name": "Project Phase",
            "key": "project_phase",
            "format": false
          },
          {
            "name": "Project Status",
            "key": "project_status",
            "format": false
          },
          {
            "name": "Project Health",
            "key": "project_health",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "ProjectManager.find_projects",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "classification_names": [
          "StudyProject"
        ]
      }
    },
    "get_additional_props": null
  },
  "Governance-Driver-DrE": {
    "target_type": "Governance Driver",
    "heading": "Governance-Driver-DrE Attributes",
    "description": "Auto-generated format for Governance Driver (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "GovernanceDriver"
        ]
      }
    },
    "get_additional_props": null
  },
  "Governance-Strategy-DrE": {
    "target_type": "Governance Strategy",
    "heading": "Governance-Strategy-DrE Attributes",
    "description": "Auto-generated format for Governance Strategy (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "GovernanceStrategy"
        ]
      }
    },
    "get_additional_props": null
  },
  "Business-Imperative-DrE": {
    "target_type": "Business Imperative",
    "heading": "Business-Imperative-DrE Attributes",
    "description": "Auto-generated format for Business Imperative (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "GovernanceDriver"
        ]
      }
    },
    "get_additional_props": null
  },
  "Regulation-DrE": {
    "target_type": "Regulation",
    "heading": "Regulation-DrE Attributes",
    "description": "Auto-generated format for Regulation (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Regulation Source",
            "key": "regulation_source",
            "format": false
          },
          {
            "name": "Regulators",
            "key": "regulators",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Regulation Source",
            "key": "regulation_source",
            "format": false
          },
          {
            "name": "Regulators",
            "key": "regulators",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "Regulation"
        ]
      }
    },
    "get_additional_props": null
  },
  "Regulation-Article-DrE": {
    "target_type": "Regulation Article",
    "heading": "Regulation-Article-DrE Attributes",
    "description": "Auto-generated format for Regulation Article (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "RegulationArticle"
        ]
      }
    },
    "get_additional_props": null
  },
  "Threat-Definition-DrE": {
    "target_type": "Threat Definition",
    "heading": "Threat-Definition-DrE Attributes",
    "description": "Auto-generated format for Threat Definition (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "ThreatDefinition"
        ]
      }
    },
    "get_additional_props": null
  },
  "Governance-Policy-DrE": {
    "target_type": "Governance Policy",
    "heading": "Governance-Policy-DrE Attributes",
    "description": "Auto-generated format for Governance Policy (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "GovernancePolicy"
        ]
      }
    },
    "get_additional_props": null
  },
  "Governance-Principle-DrE": {
    "target_type": "Governance Principle",
    "heading": "Governance-Principle-DrE Attributes",
    "description": "Auto-generated format for Governance Principle (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "GovernancePrinciple"
        ]
      }
    },
    "get_additional_props": null
  },
  "Governance-Obligation-DrE": {
    "target_type": "Governance Obligation",
    "heading": "Governance-Obligation-DrE Attributes",
    "description": "Auto-generated format for Governance Obligation (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "GovernanceObligation"
        ]
      }
    },
    "get_additional_props": null
  },
  "Governance-Approach-DrE": {
    "target_type": "Governance Approach",
    "heading": "Governance-Approach-DrE Attributes",
    "description": "Auto-generated format for Governance Approach (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "GovernanceApproach"
        ]
      }
    },
    "get_additional_props": null
  },
  "Governance-Control-DrE": {
    "target_type": "Governance Control",
    "heading": "Governance-Control-DrE Attributes",
    "description": "Auto-generated format for Governance Control (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "measurement",
            "key": "measurement",
            "format": false
          },
          {
            "name": "target",
            "key": "target",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "measurement",
            "key": "measurement",
            "format": false
          },
          {
            "name": "target",
            "key": "target",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "GovernanceMetric"
        ]
      }
    },
    "get_additional_props": null
  },
  "Governance-Action-DrE": {
    "target_type": "Governance Action",
    "heading": "Governance-Action-DrE Attributes",
    "description": "Auto-generated format for Governance Action (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "GovernanceAction"
        ]
      }
    },
    "get_additional_props": null
  },
  "Data-Processing-Purpose-DrE": {
    "target_type": "Data Processing Purpose",
    "heading": "Data-Processing-Purpose-DrE Attributes",
    "description": "Auto-generated format for Data Processing Purpose (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "DataProcessingPurpose"
        ]
      }
    },
    "get_additional_props": null
  },
  "Governance-Rule-DrE": {
    "target_type": "Governance Rule",
    "heading": "Governance-Rule-DrE Attributes",
    "description": "Auto-generated format for Governance Rule (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Document Identifier",
            "key": "document_identifier",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implementation Description",
            "key": "implementation_description",
            "format": false
          },
          {
            "name": "Supports Policies",
            "key": "supports_policies",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Document Identifier",
            "key": "document_identifier",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implementation Description",
            "key": "implementation_description",
            "format": false
          },
          {
            "name": "Supports Policies",
            "key": "supports_policies",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "GovernanceRule"
        ]
      }
    },
    "get_additional_props": null
  },
  "Service-Level-Objectives-DrE": {
    "target_type": "Service Level Objectives",
    "heading": "Service-Level-Objectives-DrE Attributes",
    "description": "Auto-generated format for Service Level Objectives (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Document Identifier",
            "key": "document_identifier",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implementation Description",
            "key": "implementation_description",
            "format": false
          },
          {
            "name": "Supports Policies",
            "key": "supports_policies",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Document Identifier",
            "key": "document_identifier",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implementation Description",
            "key": "implementation_description",
            "format": false
          },
          {
            "name": "Supports Policies",
            "key": "supports_policies",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "ServiceLevelObjectives"
        ]
      }
    },
    "get_additional_props": null
  },
  "Governance-Responsibility-DrE": {
    "target_type": "Governance Responsibility",
    "heading": "Governance-Responsibility-DrE Attributes",
    "description": "Auto-generated format for Governance Responsibility (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Document Identifier",
            "key": "document_identifier",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implementation Description",
            "key": "implementation_description",
            "format": false
          },
          {
            "name": "Supports Policies",
            "key": "supports_policies",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Document Identifier",
            "key": "document_identifier",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implementation Description",
            "key": "implementation_description",
            "format": false
          },
          {
            "name": "Supports Policies",
            "key": "supports_policies",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "GovernanceResponsibility"
        ]
      }
    },
    "get_additional_props": null
  },
  "Governance-Procedure-DrE": {
    "target_type": "Governance Procedure",
    "heading": "Governance-Procedure-DrE Attributes",
    "description": "Auto-generated format for Governance Procedure (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Document Identifier",
            "key": "document_identifier",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implementation Description",
            "key": "implementation_description",
            "format": false
          },
          {
            "name": "Supports Policies",
            "key": "supports_policies",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Document Identifier",
            "key": "document_identifier",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implementation Description",
            "key": "implementation_description",
            "format": false
          },
          {
            "name": "Supports Policies",
            "key": "supports_policies",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "GovernanceProcedure"
        ]
      }
    },
    "get_additional_props": null
  },
  "Security-Access-Control-DrE": {
    "target_type": "Security Access Control",
    "heading": "Security-Access-Control-DrE Attributes",
    "description": "Auto-generated format for Security Access Control (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "SecurityAccessControl"
        ]
      }
    },
    "get_additional_props": null
  },
  "security_access_control-DrE": {
    "target_type": "security_access_control",
    "heading": "security_access_control-DrE Attributes",
    "description": "Auto-generated format for security_access_control (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "criteria",
            "key": "criteria",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "criteria",
            "key": "criteria",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "GovernanceZone"
        ]
      }
    },
    "get_additional_props": null
  },
  "Security-Group-DrE": {
    "target_type": "Security Group",
    "heading": "Security-Group-DrE Attributes",
    "description": "Auto-generated format for Security Group (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "SEcurityGroup"
        ]
      }
    },
    "get_additional_props": null
  },
  "Naming-Standard-Rule-DrE": {
    "target_type": "Naming Standard Rule",
    "heading": "Naming-Standard-Rule-DrE Attributes",
    "description": "Auto-generated format for Naming Standard Rule (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Document Identifier",
            "key": "document_identifier",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implementation Description",
            "key": "implementation_description",
            "format": false
          },
          {
            "name": "Supports Policies",
            "key": "supports_policies",
            "format": false
          },
          {
            "name": "Name Patterns",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Document Identifier",
            "key": "document_identifier",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implementation Description",
            "key": "implementation_description",
            "format": false
          },
          {
            "name": "Supports Policies",
            "key": "supports_policies",
            "format": false
          },
          {
            "name": "Name Patterns",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "NamingStandardRule"
        ]
      }
    },
    "get_additional_props": null
  },
  "Certification-Type-DrE": {
    "target_type": "Certification Type",
    "heading": "Certification-Type-DrE Attributes",
    "description": "Auto-generated format for Certification Type (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Document Identifier",
            "key": "document_identifier",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Details",
            "key": "details",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          },
          {
            "name": "Restrictions",
            "key": "restrictions",
            "format": false
          },
          {
            "name": "Obligations",
            "key": "obligations",
            "format": false
          },
          {
            "name": "Entitlements",
            "key": "Entitlements",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Document Identifier",
            "key": "document_identifier",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Details",
            "key": "details",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          },
          {
            "name": "Restrictions",
            "key": "restrictions",
            "format": false
          },
          {
            "name": "Obligations",
            "key": "obligations",
            "format": false
          },
          {
            "name": "Entitlements",
            "key": "Entitlements",
            "format": false
          }
        ]
      }
    ],
    "action": null,
    "get_additional_props": null
  },
  "License-Type-DrE": {
    "target_type": "License Type",
    "heading": "License-Type-DrE Attributes",
    "description": "Auto-generated format for License Type (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Document Identifier",
            "key": "document_identifier",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Details",
            "key": "details",
            "format": false
          },
          {
            "name": "Restrictions",
            "key": "restrictions",
            "format": false
          },
          {
            "name": "Obligations",
            "key": "obligations",
            "format": false
          },
          {
            "name": "Entitlements",
            "key": "Entitlements",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Document Identifier",
            "key": "document_identifier",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Details",
            "key": "details",
            "format": false
          },
          {
            "name": "Restrictions",
            "key": "restrictions",
            "format": false
          },
          {
            "name": "Obligations",
            "key": "obligations",
            "format": false
          },
          {
            "name": "Entitlements",
            "key": "Entitlements",
            "format": false
          }
        ]
      }
    ],
    "action": null,
    "get_additional_props": null
  }
}